ExperienceCampaignsResult class
Response containing fetched experience campaigns and any failures.
Constructors
-
ExperienceCampaignsResult({required List<
ExperienceCampaign> experiences, required List<ExperienceCampaignFailure> failures}) - ExperienceCampaignsResult Constructor
Properties
-
experiences
→ List<
ExperienceCampaign> -
Successfully resolved experience campaigns.
final
-
failures
→ List<
ExperienceCampaignFailure> -
Failures for experience keys that could not be resolved.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited